@@ -27,10 +27,11 @@ import sys
 import logging
 import argparse
 import fs
+import humanfriendly
 from PyQt5 import QtWidgets, QtCore
 from PyQt5.QtGui import QIcon
 from fslib import ui_filepicker, __version__
-from fslib.utils import match_extension, WidgetImageText
+from fslib.utils import match_extension, WidgetImageText, WidgetText
 from fslib.icons import icons
 from fslib.utils import root_url
 
@@ -126,7 +127,12 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.fs.close()
         if self.wparm is not None:
             self.wparm = None
-        self.fs = fs.open_fs(self.active_url)
+        try:
+            self.fs = fs.open_fs(self.active_url)
+        # ToDo lookup external library why it is not e.g. OpenFailed
+        except fs.errors.CreateFailed:
+            logging.error(u"{} does not exist!".format(self.active_url))
+            exit()
         self.browse_folder()
         self.selection_directory()
 
@@ -180,10 +186,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         file_type = self.ui_FileType.text()
         self.file_list_items = []
         self.dir_list_items = []
-        self.ui_FileList.setColumnCount(1)
-        self.ui_FileList.setColumnWidth(0, 400)
         self.ui_FileList.verticalHeader().setVisible(False)
-        self.ui_FileList.horizontalHeader().setVisible(False)
+        self.ui_FileList.horizontalHeader().setVisible(True)
+        self.ui_FileList.setHorizontalHeaderLabels([u'Name', u'Size', u'Modified'])
         self.ui_FileList.setShowGrid(False)
         self.ui_FileList.setSizeAdjustPolicy(
             QtWidgets.QAbstractScrollArea.AdjustToContents)
@@ -193,28 +198,60 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         else:
             _sel_dir = self.selected_dir
         # don't scan on clear
-        if not _sel_dir == "":
+        if not _sel_dir == u"":
             try:
-                 for item in sorted(self.fs.listdir(_sel_dir)):
+                for item in sorted(self.fs.listdir(_sel_dir)):
                     _item = fs.path.combine(_sel_dir, item)
                     try:
                         if not self.fs.isdir(_item) and match_extension(item, [file_type]):
-                            self.file_list_items.append(_item)
+                            try:
+                                info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
+                            except (fs.errors.ResourceNotFound, UnicodeEncodeError):
+                                info = None
+                            self.file_list_items.append({_item: info})
                         elif self.fs.isdir(_item):
-                            self.dir_list_items.append(_item)
+                            try:
+                                info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
+                            except (fs.errors.ResourceNotFound, UnicodeEncodeError):
+                                info = None
+                            self.dir_list_items.append({_item: info})
                     except fs.errors.PermissionDenied:
-                        logging.info("can't access {}".format(item))
+                        logging.info(u"can't access {}".format(item))
             except UnicodeDecodeError as e:
-                logging.error("Error: {}".format(e))
+                logging.error(u"Error: {}".format(e))
 
         self.ui_FileList.setRowCount(len(self.file_list_items) + len(self.dir_list_items))
         index = 0
-
         for item in self.dir_list_items:
-            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item), self.dir_icon, item))
+            info = item.values()[0]
+            try:
+                _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
+            except TypeError:
+                _mod_time = u""
+            try:
+                _size = unicode(humanfriendly.format_size(info.size))
+            except (AttributeError, TypeError):
+                _size = u""
+
+            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item.keys()[0]),
+                                                                     self.dir_icon, item))
+            self.ui_FileList.setCellWidget(index, 1, WidgetText(_size))
+            self.ui_FileList.setCellWidget(index, 2, WidgetText(_mod_time))
             index = index + 1
         for item in self.file_list_items:
-            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item), self.file_icon, item))
+            info = item.values()[0]
+            try:
+                _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
+            except (AttributeError, TypeError):
+                _mod_time = u""
+            try:
+                _size = unicode(humanfriendly.format_size(info.size))
+            except (AttributeError, TypeError):
+                _size = u""
+            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(item.keys()[0]),
+                                                                     self.file_icon, item))
+            self.ui_FileList.setCellWidget(index, 1, WidgetText(_size))
+            self.ui_FileList.setCellWidget(index, 2, WidgetText(_mod_time))
             index = index + 1
         if self.last_index == 0 and not self.show_save_action:
             self.ui_FileList.clearSelection()
@@ -230,6 +267,8 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         :param row: position
         :param column: position
         """
+        # Any cell click is always in column 0
+        column = 0
         self.wparm = self.ui_FileList.cellWidget(row, column)
         if self.wparm is not None:
             if "text" in self.wparm.img:
@@ -242,13 +281,17 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         :param row: position
         :param column: position
         """
+        column = 0
         self.wparm = self.ui_FileList.cellWidget(row, column)
-        if self.wparm is not None:
-            if "folder" in self.wparm.img:
-                self.directory_history.append(self.wparm.value)
-                index = self.dir_list_items.index(self.wparm.value) + 1
-                if index != 0:
-                    self.browse_folder(subdir=self.wparm.value)
+        try:
+            if self.wparm is not None:
+                if "folder" in self.wparm.img:
+                    _folder_names = [name.keys()[0] for name in self.dir_list_items]
+                    self.directory_history.append(self.wparm.value.keys()[0])
+                    index = _folder_names.index(self.wparm.value.keys()[0])
+                    self.browse_folder(subdir=self.wparm.value.keys()[0])
+        except AttributeError:
+            pass
 
     def selection_file_type(self):
         """
@@ -266,15 +309,16 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.filename = self.ui_SelectedName.text()
         dirname = u'./'
         if self.wparm is not None:
-            if self.wparm.value == './{}'.format(self.wparm.text):
-                dirname = fs.path.dirname('./{}'.format(self.wparm.text))
+            if self.wparm.value == u'./{}'.format(self.wparm.text):
+                dirname = fs.path.dirname(u'./{}'.format(self.wparm.text))
             else:
-                dirname = fs.path.dirname(self.wparm.value)
+                dirname = fs.path.dirname(self.wparm.value.keys()[0])
         _filename = fs.path.combine(dirname, self.filename)
+        _file_names = [name.keys()[0] for name in self.file_list_items]
 
-        if self.fs.exists(_filename) and _filename in self.file_list_items:
+        if self.fs.exists(_filename) and _filename in _file_names:
             self.ui_Action.setEnabled(True)
-            all_items = self.dir_list_items + self.file_list_items
+            all_items = self.dir_list_items + _file_names
             try:
                 self.ui_FileList.selectRow(all_items.index(_filename))
             except TypeError:
@@ -321,7 +365,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         """
         Shows the make dir dialog und creates a new directory
         """
-        new_dir_name, ok = QtWidgets.QInputDialog.getText(self, u"New Folder", "Enter a new folder name:",
+        new_dir_name, ok = QtWidgets.QInputDialog.getText(self, u"New Folder", u"Enter a new folder name:",
                                                           QtWidgets.QLineEdit.Normal, "")
 
         if ok:
@@ -335,8 +379,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 self.last_dir_index = list(reversed(self.directory_history)).index(self.selected_dir)
                 self.browse_folder(subdir=self.selected_dir)
             else:
-                ok = QtWidgets.QMessageBox.warning(self, "New Folder", "Can't create this Folder: {}".format(new_dir))
-
+                ok = QtWidgets.QMessageBox.warning(self, u"New Folder", u"Can't create this Folder: {}".format(new_dir))
 
     def history_top(self):
         """
@@ -370,25 +413,25 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                 return
             dirname = u'./'
             if self.wparm is not None:
-                if self.wparm.value == './{}'.format(self.wparm.text):
-                    dirname = fs.path.dirname('./{}'.format(self.wparm.text))
+                if self.wparm.value == u'./{}'.format(self.wparm.text):
+                    dirname = fs.path.dirname(u'./{}'.format(self.wparm.text))
                 else:
                     dirname = fs.path.dirname(self.wparm.value)
             filename = fs.path.join(dirname, self.filename)
             if self.fs.isdir(filename):
                 sel = QtWidgets.QMessageBox.warning(
-                    self, "Warning",
-                    "You can't create a file with this name: {0}".format(self.filename),
+                    self, u"Warning",
+                    u"You can't create a file with this name: {0}".format(self.filename),
                     QtWidgets.QMessageBox.No)
             elif self.fs.exists(filename):
                 sel = QtWidgets.QMessageBox.question(
-                    self, "Replace Filename",
-                    "This will replace the filename: {0}. Continue?".format(self.filename),
+                    self, u"Replace Filename",
+                    u"This will replace the filename: {0}. Continue?".format(self.filename),
                     QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
                 if sel == QtWidgets.QMessageBox.Yes:
                     self.close()
                 else:
-                    self.close()
+                    pass
             else:
                 self.close()
         else:
